@@ -1,5 +1,6 @@
 ;;; GNU Mes --- Maxwell Equations of Software
-;;; Copyright © 2016,2017,2018,2019,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2016,2017,2018,2019,2020,2021 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
 ;;;
 ;;; This file is part of GNU Mes.
 ;;;
@@ -198,7 +199,7 @@
          (verbose? (count-opt options 'verbose))
          (M1 (or (getenv "M1") "M1"))
          (command `(,M1
-                    "--LittleEndian"
+                    "--little-endian"
                     ,@(arch-get-architecture options)
                     "-f" ,(arch-find options (arch-get-m1-macros options))
                     ,@(append-map (cut list "-f" <>) M1-files)
@@ -225,16 +226,15 @@
                               (option-ref options 'nostdlib #f)) '()
                               `("-f" ,(arch-find options "crt1.o"))))
          (command `(,hex2
-                    "--LittleEndian"
+                    "--little-endian"
                     ,@(arch-get-architecture options)
-                    "--BaseAddress" ,base-address
+                    "--base-address" ,base-address
                     "-f" ,(kernel-find
                            options
                            (string-append "elf" machine "-header.hex2"))
                     ,@start-files
                     ,@(append-map (cut list "-f" <>) hex2-files)
                     "-f" ,elf-footer
-                    "--exec_enable"
                     "-o" ,elf-file-name)))
     (when (and verbose? (> verbose? 1))
       (stderr "~a\n" (string-join command)))
@@ -249,9 +249,10 @@
          (verbose? (count-opt options 'verbose))
          (blood-elf (or (getenv "BLOOD_ELF") "blood-elf"))
          (command `(,blood-elf
-                      "-f" ,(arch-find options (arch-get-m1-macros options))
-                      ,@(append-map (cut list "-f" <>) M1-files)
-                      "-o" ,M1-blood-elf-footer)))
+                    ,@(if (equal? (arch-get-machine options) "64") '("--64") '())
+                    "-f" ,(arch-find options (arch-get-m1-macros options))
+                    ,@(append-map (cut list "-f" <>) M1-files)
+                    "-o" ,M1-blood-elf-footer)))
     (when (and verbose? (> verbose? 1))
       (format (current-error-port) "~a\n" (string-join command)))
     (and (zero? (apply assert-system* command))
@@ -359,10 +360,11 @@
 
 (define (arch-get-machine options)
   (let* ((machine (option-ref options 'machine #f))
-         (arch (option-ref options 'arch #f)))
-    (or machine
-        (if (member arch '("x86_64")) "64"
-            "32"))))
+         (arch (option-ref options 'arch #f))
+         (machine (or machine arch "32")))
+    (cond ((member machine '("64" "x86_64")) "64")
+          ((member machine '("arm")) "32")
+          (else "32"))))
 
 (define (arch-get-m1-macros options)
   (let ((arch (arch-get options)))
